@@ -106,6 +106,7 @@ def sync(client=None, force=False, verbose=True):
     """
     from mediasync import backends
     from mediasync.conf import msettings
+    from mediasync.signals import pre_sync, post_sync
 
     # create client connection
     if client is None:
@@ -114,6 +115,9 @@ def sync(client=None, force=False, verbose=True):
     client.open()
     client.serve_remote = True
 
+    # send pre-sync signal
+    pre_sync.send(sender=client)
+
     #
     # sync joined media
     #
@@ -126,7 +130,7 @@ def sync(client=None, force=False, verbose=True):
             continue
         filedata, dirname = filedata
 
-        content_type = mimetypes.guess_type(joinfile)[0] or 'application/octet-stream'
+        content_type = mimetypes.guess_type(joinfile)[0] or msettings['DEFAULT_MIMETYPE']
 
         remote_path = joinfile
         if dirname:
@@ -152,7 +156,7 @@ def sync(client=None, force=False, verbose=True):
                 filepath = os.path.join(dirpath, filename)
                 remote_path = "%s/%s" % (dirname, filename)
 
-                content_type = mimetypes.guess_type(filepath)[0] or 'application/octet-stream'
+                content_type = mimetypes.guess_type(filepath)[0] or msettings['DEFAULT_MIMETYPE']
 
                 if not is_syncable_file(os.path.basename(filename)) or not os.path.isfile(filepath):
                     continue # hidden file or directory, do not upload
@@ -162,9 +166,12 @@ def sync(client=None, force=False, verbose=True):
                 if client.process_and_put(filedata, content_type, remote_path, force=force):
                     if verbose:
                         print "[%s] %s" % (content_type, remote_path)
-                        
+    
+    # send post-sync signal while client is still open
+    post_sync.send(sender=client)
+    
     client.close()
 
 
 __all__ = ['sync', 'SyncException']
-__version__ = '2.1.0'
+__version__ = '2.2.0'
