@@ -72,7 +72,7 @@ class Client(BaseClient):
             "x-amz-acl": "public-read",
             "Content-Type": content_type,
             "Expires": expires,
-            "Cache-Control": 'max-age=%d' % (self.expiration_days * 24 * 3600),
+            "Cache-Control": 'max-age=%d, public' % (self.expiration_days * 24 * 3600),
         }
         
         key = self._bucket.get_key(remote_path)
