@@ -1,4 +1,5 @@
 from django.conf import settings
+from mediasync import CSS_MIMETYPES, JS_MIMETYPES
 import os
 from subprocess import Popen, PIPE
 
@@ -11,7 +12,7 @@ def _yui_path(settings):
     return path
 
 def css_minifier(filedata, content_type, remote_path, is_active):
-    is_css = (content_type == 'text/css' or remote_path.lower().endswith('.css'))
+    is_css = (content_type in CSS_MIMETYPES or remote_path.lower().endswith('.css'))
     yui_path = _yui_path(settings)
     if is_css and yui_path and is_active:
         proc = Popen(['java', '-jar', yui_path, '--type', 'css'], stdout=PIPE,
@@ -20,7 +21,7 @@ def css_minifier(filedata, content_type, remote_path, is_active):
         return str(stdout)
 
 def js_minifier(filedata, content_type, remote_path, is_active):
-    is_js = (content_type == 'text/javascript' or remote_path.lower().endswith('.js'))
+    is_js = (content_type in JS_MIMETYPES or remote_path.lower().endswith('.js'))
     yui_path = _yui_path(settings)
     if is_js and yui_path and is_active:
         proc = Popen(['java', '-jar', yui_path, '--type', 'js'], stdout=PIPE,
