@@ -1,6 +1,9 @@
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
+from django.dispatch import receiver
+from django.template import Context, Template
 from hashlib import md5
+import glob
 import httplib
 import itertools
 import os
@@ -8,9 +11,10 @@ import re
 import time
 import unittest
 
-from mediasync import backends
+from mediasync import backends, JS_MIMETYPES, listdir_recursive
 from mediasync.backends import BaseClient
 from mediasync.conf import msettings
+from mediasync.signals import pre_sync, post_sync, sass_receiver
 import mediasync
 import mimetypes
 
@@ -30,7 +34,7 @@ class Client(BaseClient):
         super(Client, self).__init__(*args, **kwargs)
     
     def put(self, filedata, content_type, remote_path, force=False):
-        if self.put_callback:
+        if hasattr(self, 'put_callback'):
             return self.put_callback(filedata, content_type, remote_path, force)
         else:
             return True
@@ -101,6 +105,7 @@ class MockClientTestCase(unittest.TestCase):
         allowed_files = [
             'css/1.css',
             'css/2.css',
+            'css/3.scss',
             'img/black.png',
             'js/1.js',
             'js/2.js',
@@ -114,6 +119,7 @@ class MockClientTestCase(unittest.TestCase):
         to_sync = {
             'css/1.css': 'text/css',
             'css/2.css': 'text/css',
+            'css/3.scss': msettings['DEFAULT_MIMETYPE'],
             'css/joined.css': 'text/css',
             'img/black.png': 'image/png',
             'js/1.js': 'application/javascript',
@@ -176,7 +182,7 @@ class S3ClientTestCase(unittest.TestCase):
     def testSync(self):
         
         # calculate cache control
-        cc = "max-age=%i" % (self.client.expiration_days * 24 * 3600)
+        cc = "max-age=%i, public" % (self.client.expiration_days * 24 * 3600)
         
         # do a sync then reopen client
         mediasync.sync(self.client, force=True, verbose=False)
@@ -217,7 +223,7 @@ class S3ClientTestCase(unittest.TestCase):
             response.read()
             
             # verify valid content type
-            content_type = mimetypes.guess_type(path)[0] or 'application/octet-stream'
+            content_type = mimetypes.guess_type(path)[0] or msettings['DEFAULT_MIMETYPE']
             self.assertEqual(response.getheader("Content-Type", None), content_type)
             
             # check for valid expires headers
@@ -305,3 +311,159 @@ class ProcessorTestCase(unittest.TestCase):
     def testCustomProcessor(self):
         procd = self.client.process('asdf', 'text/plain', 'asdf.txt')
         self.assertEqual(procd, "ASDF")
+
+class ClosureCompilerTestCase(unittest.TestCase):
+    
+    def setUp(self):
+        msettings['SERVE_REMOTE'] = True
+        msettings['BACKEND'] = 'mediasync.tests.tests'
+        msettings['PROCESSORS'] = (
+            'mediasync.processors.closurecompiler.compile',
+        )
+        self.client = backends.client()
+    
+    def testCompiler(self):
+        
+        content = """var foo = function() {
+            alert(1);
+        };"""
+        
+        for ct in JS_MIMETYPES:
+            procd = self.client.process(content, ct, 'test.js')
+            self.assertEqual(procd, 'var foo=function(){alert(1)};\n')
+    
+    def testNotJavascript(self):
+        
+        content = """html {
+            border: 1px solid #000000;
+            font-family: "Helvetica", "Arial", sans-serif;
+        }"""
+        
+        procd = self.client.process(content, 'text/css', 'test.css')
+        self.assertEqual(procd, content)
+
+class SignalTestCase(unittest.TestCase):
+    
+    def setUp(self):
+        msettings['BACKEND'] = 'mediasync.tests.tests'
+        self.client = backends.client()
+    
+    def tearDown(self):
+        root = msettings['STATIC_ROOT']
+        for filename in glob.glob(os.path.join(root, "*/*.s[ac]ss")):
+            path = filename[:-4] + "css"
+            if os.path.exists(path):
+                os.unlink(path)
+    
+    def testSyncSignals(self):
+        
+        self.client.called_presync = False
+        self.client.called_postsync = False
+        
+        @receiver(pre_sync, weak=False)
+        def presync_receiver(sender, **kwargs):
+            self.assertEqual(self.client, sender)
+            sender.called_presync = True
+        
+        @receiver(post_sync, weak=False)
+        def postsync_receiver(sender, **kwargs):
+            self.assertEqual(self.client, sender)
+            sender.called_postsync = True
+            
+        mediasync.sync(self.client, force=True, verbose=False)
+        
+        self.assertTrue(self.client.called_presync)
+        self.assertTrue(self.client.called_postsync)
+    
+    def testSassReceiver(self):
+        
+        pre_sync.connect(sass_receiver)
+        
+        mediasync.sync(self.client, force=True, verbose=False)
+        
+        root = msettings['STATIC_ROOT']
+        
+        for sass_path in glob.glob(os.path.join(root, "*/*.s[ac]ss")):
+            css_path = sass_path[:-4] + "css"
+            self.assertTrue(os.path.exists(css_path))
+
+class TemplateTagTestCase(unittest.TestCase):
+    
+    def setUp(self):
+        msettings['BACKEND'] = 'mediasync.tests.tests'
+        msettings['DOCTYPE'] = 'html5'
+        self.client = backends.client()
+    
+    def testMediaURLTag(self):
+        
+        pathvar = 'images/logo.png'
+        c = Context({'pathvar': pathvar})
+        
+        # base media url
+        t = Template('{% load media %}{% media_url %}')
+        self.assertEqual(t.render(c), "http://localhost")
+        
+        # media url with string argument
+        t = Template('{%% load media %%}{%% media_url "%s" %%}' % pathvar)
+        self.assertEqual(t.render(c), "http://localhost/images/logo.png")
+        
+        # media url with variable argument
+        t = Template('{% load media %}{% media_url pathvar %}')
+        self.assertEqual(t.render(c), "http://localhost/images/logo.png")
+    
+    def testCSSTag(self):
+        
+        pathvar = 'styles/reset.css'
+        c = Context({'pathvar': pathvar})
+        
+        # css tag with string argument
+        t = Template('{%% load media %%}{%% css "%s" %%}' % pathvar)
+        self.assertEqual(
+            t.render(c),
+            '<link rel="stylesheet" href="http://localhost/%s" media="screen, projection">' % pathvar)
+
+        # css tag with string argument and explicit media type
+        t = Template('{%% load media %%}{%% css "%s" "tv" %%}' % pathvar)
+        self.assertEqual(
+            t.render(c),
+            '<link rel="stylesheet" href="http://localhost/%s" media="tv">' % pathvar)
+        
+        # css tag with variable argument
+        t = Template('{% load media %}{% css pathvar %}')
+        self.assertEqual(
+            t.render(c),
+            '<link rel="stylesheet" href="http://localhost/%s" media="screen, projection">' % pathvar)
+
+        # css tag with variable argument and explicit media type
+        t = Template('{% load media %}{% css pathvar "tv" %}')
+        self.assertEqual(
+            t.render(c),
+            '<link rel="stylesheet" href="http://localhost/%s" media="tv">' % pathvar)
+    
+    def testJSTag(self):
+
+        pathvar = 'scripts/jquery.js'
+        c = Context({'pathvar': pathvar})
+        
+        # js tag with string argument
+        t = Template('{%% load media %%}{%% js "%s" %%}' % pathvar)
+        self.assertEqual(
+            t.render(c),
+            '<script src="http://localhost/%s"></script>' % pathvar)
+        
+        # js tag with variable argument
+        t = Template('{% load media %}{% js pathvar %}')
+        self.assertEqual(
+            t.render(c),
+            '<script src="http://localhost/%s"></script>' % pathvar)
+    
+    def testMultipleTags(self):
+        
+        paths = ('scripts/1.js','scripts/2.js')
+        c = Context({'paths': paths})
+        
+        t = Template('{% load media %}{% for path in paths %}{% media_url path %}{% endfor %}')
+        self.assertEqual(
+            t.render(c),
+            'http://localhost/scripts/1.jshttp://localhost/scripts/2.js')
+        
\ No newline at end of file
